@@ -27,8 +27,18 @@ Grammar:
     expr -> '$' pyexpr | '$(' pyexpr ')' | '${' pyexpr '}'
     pyexpr -> <python expression>
 """
-from __future__ import print_function
+
+import ast
+import glob
+import os
+import sys
+import tokenize
 from io import open
+import builtins
+
+from .net import websafe
+from .utils import re_compile, safestr, safeunicode, storage
+from .webapi import config
 
 __all__ = [
     "Template",
@@ -40,27 +50,8 @@ __all__ = [
     "test",
 ]
 
-import tokenize
-import os
-import sys
-import glob
-import ast
 
-from .utils import storage, safeunicode, safestr, re_compile
-from .webapi import config
-from .net import websafe
-from .py3helpers import PY2
-
-if PY2:
-    from UserDict import DictMixin
-
-    # Make a new-style class
-    class MutableMapping(object, DictMixin):
-        pass
-
-
-else:
-    from collections.abc import MutableMapping
+from collections.abc import MutableMapping
 
 
 def splitline(text):
@@ -82,8 +73,7 @@ def splitline(text):
 
 
 class Parser:
-    """Parser Base.
-    """
+    """Parser Base."""
 
     def __init__(self):
         self.statement_nodes = STATEMENT_NODES
@@ -138,11 +128,11 @@ class Parser:
     def read_var(self, text):
         r"""Reads a var statement.
 
-            >>> read_var = Parser().read_var
-            >>> read_var('var x=10\nfoo')
-            (<var: x = 10>, 'foo')
-            >>> read_var('var x: hello $name\nfoo')
-            (<var: x = join_(u'hello ', escape_(name, True))>, 'foo')
+        >>> read_var = Parser().read_var
+        >>> read_var('var x=10\nfoo')
+        (<var: x = 10>, 'foo')
+        >>> read_var('var x: hello $name\nfoo')
+        (<var: x = join_(u'hello ', escape_(name, True))>, 'foo')
         """
         line, text = splitline(text)
         tokens = self.python_tokens(line)
@@ -176,9 +166,9 @@ class Parser:
     def read_suite(self, text):
         r"""Reads section by section till end of text.
 
-            >>> read_suite = Parser().read_suite
-            >>> read_suite('hello $name\nfoo\n')
-            [<line: [t'hello ', $name, t'\n']>, <line: [t'foo\n']>]
+        >>> read_suite = Parser().read_suite
+        >>> read_suite('hello $name\nfoo\n')
+        [<line: [t'hello ', $name, t'\n']>, <line: [t'foo\n']>]
         """
         sections = []
         while text:
@@ -187,19 +177,19 @@ class Parser:
         return SuiteNode(sections)
 
     def readline(self, text):
-        r"""Reads one line from the text. Newline is supressed if the line ends with \.
+        r"""Reads one line from the text. Newline is suppressed if the line ends with \.
 
-            >>> readline = Parser().readline
-            >>> readline('hello $name!\nbye!')
-            (<line: [t'hello ', $name, t'!\n']>, 'bye!')
-            >>> readline('hello $name!\\\nbye!')
-            (<line: [t'hello ', $name, t'!']>, 'bye!')
-            >>> readline('$f()\n\n')
-            (<line: [$f(), t'\n']>, '\n')
+        >>> readline = Parser().readline
+        >>> readline('hello $name!\nbye!')
+        (<line: [t'hello ', $name, t'!\n']>, 'bye!')
+        >>> readline('hello $name!\\\nbye!')
+        (<line: [t'hello ', $name, t'!']>, 'bye!')
+        >>> readline('$f()\n\n')
+        (<line: [$f(), t'\n']>, '\n')
         """
         line, text = splitline(text)
 
-        # supress new line if line ends with \
+        # suppress new line if line ends with \
         if line.endswith("\\\n"):
             line = line[:-2]
 
@@ -213,11 +203,11 @@ class Parser:
     def read_node(self, text):
         r"""Reads a node from the given text and returns the node and remaining text.
 
-            >>> read_node = Parser().read_node
-            >>> read_node('hello $name')
-            (t'hello ', '$name')
-            >>> read_node('$name')
-            ($name, '')
+        >>> read_node = Parser().read_node
+        >>> read_node('hello $name')
+        (t'hello ', '$name')
+        >>> read_node('$name')
+        ($name, '')
         """
         if text.startswith("$$"):
             return TextNode("$"), text[2:]
@@ -238,9 +228,9 @@ class Parser:
     def read_text(self, text):
         r"""Reads a text node from the given text.
 
-            >>> read_text = Parser().read_text
-            >>> read_text('hello $name')
-            (t'hello ', '$name')
+        >>> read_text = Parser().read_text
+        >>> read_text('hello $name')
+        (t'hello ', '$name')
         """
         index = text.find("$")
         if index < 0:
@@ -365,8 +355,6 @@ class Parser:
                 self.position += 1
                 return self.current_item
 
-            next = __next__  # Needed for Py2 compatibility
-
         tokens = BetterIter(get_tokens(text))
 
         if tokens.lookahead().value in parens:
@@ -379,9 +367,9 @@ class Parser:
     def read_assignment(self, text):
         r"""Reads assignment statement from text.
 
-            >>> read_assignment = Parser().read_assignment
-            >>> read_assignment('a = b + 1\nfoo')
-            (<assignment: 'a = b + 1'>, 'foo')
+        >>> read_assignment = Parser().read_assignment
+        >>> read_assignment('a = b + 1\nfoo')
+        (<assignment: 'a = b + 1'>, 'foo')
         """
         line, text = splitline(text)
         return AssignmentNode(line.strip()), text
@@ -389,13 +377,13 @@ class Parser:
     def python_lookahead(self, text):
         """Returns the first python token from the given text.
 
-            >>> python_lookahead = Parser().python_lookahead
-            >>> python_lookahead('for i in range(10):')
-            'for'
-            >>> python_lookahead('else:')
-            'else'
-            >>> python_lookahead(' x = 1')
-            ' '
+        >>> python_lookahead = Parser().python_lookahead
+        >>> python_lookahead('for i in range(10):')
+        'for'
+        >>> python_lookahead('else:')
+        'else'
+        >>> python_lookahead(' x = 1')
+        ' '
         """
         i = iter([text])
         readline = lambda: next(i)
@@ -438,9 +426,9 @@ class Parser:
     def read_statement(self, text):
         r"""Reads a python statement.
 
-            >>> read_statement = Parser().read_statement
-            >>> read_statement('for i in range(10): hello $name')
-            ('for i in range(10):', ' hello $name')
+        >>> read_statement = Parser().read_statement
+        >>> read_statement('for i in range(10): hello $name')
+        ('for i in range(10):', ' hello $name')
         """
         tok = PythonTokenizer(text)
         tok.consume_till(":")
@@ -509,12 +497,12 @@ class PythonTokenizer:
     def consume_till(self, delim):
         """Consumes tokens till colon.
 
-            >>> tok = PythonTokenizer('for i in range(10): hello $i')
-            >>> tok.consume_till(':')
-            >>> tok.text[:tok.index]
-            'for i in range(10):'
-            >>> tok.text[tok.index:]
-            ' hello $i'
+        >>> tok = PythonTokenizer('for i in range(10): hello $i')
+        >>> tok.consume_till(':')
+        >>> tok.text[:tok.index]
+        'for i in range(10):'
+        >>> tok.text[tok.index:]
+        ' hello $i'
         """
         try:
             while True:
@@ -547,8 +535,6 @@ class PythonTokenizer:
         self.index = col
         return storage(type=type, value=t, begin=begin, end=end)
 
-    next = __next__  # needed for Py2 compatibility
-
 
 class DefwithNode:
     def __init__(self, defwith, suite):
@@ -795,10 +781,6 @@ TEMPLATE_BUILTIN_NAMES = [
     "__import__",  # some c-libraries like datetime requires __import__ to present in the namespace
 ]
 
-if PY2:
-    import __builtin__ as builtins
-else:
-    import builtins
 TEMPLATE_BUILTINS = dict(
     [
         (name, getattr(builtins, name))
@@ -846,8 +828,7 @@ class ForLoop:
 
 
 class ForLoopContext:
-    """Stackable context for ForLoop to support nested for loops.
-    """
+    """Stackable context for ForLoop to support nested for loops."""
 
     def __init__(self, forloop, parent):
         self._forloop = forloop
@@ -893,7 +874,7 @@ class BaseTemplate:
         return env["__template__"]
 
     def __call__(self, *a, **kw):
-        __hidetraceback__ = True
+        __hidetraceback__ = True  # noqa: F841
         return self.t(*a, **kw)
 
     def make_env(self, globals, builtins):
@@ -959,13 +940,20 @@ class Template(BaseTemplate):
             builtins=builtins,
         )
 
+    def __repr__(self):
+        """
+        >>> Template(text='Template text', filename='burndown_chart.html')
+        <Template burndown_chart.html>
+        """
+        return "<{} {}>".format(self.__class__.__name__, self.filename)
+
     def normalize_text(text):
         """Normalizes template text by correcting \r\n, tabs and BOM chars."""
         text = text.replace("\r\n", "\n").replace("\r", "\n").expandtabs()
         if not text.endswith("\n"):
             text += "\n"
 
-        # ignore BOM chars at the begining of template
+        # ignore BOM chars at the beginning of template
         BOM = "\xef\xbb\xbf"
         if isinstance(text, str) and text.startswith(BOM):
             text = text[len(BOM) :]
@@ -977,7 +965,7 @@ class Template(BaseTemplate):
     normalize_text = staticmethod(normalize_text)
 
     def __call__(self, *a, **kw):
-        __hidetraceback__ = True
+        __hidetraceback__ = True  # noqa: F841
         from . import webapi as web
 
         if "headers" in web.ctx and self.content_type:
@@ -1019,7 +1007,6 @@ class Template(BaseTemplate):
             compiled_code = compile(code, filename, "exec")
         except SyntaxError as err:
             # display template line that caused the error along with the traceback.
-            # this works in Py3 but not Py2, duh ? TODO
             err.msg += "\n\nTemplate traceback:\n    File %s, line %s\n        %s" % (
                 repr(err.filename),
                 err.lineno,
@@ -1104,9 +1091,8 @@ class Render:
                 path, cache=self._cache is not None, base=self._base, **self._keywords
             )
         elif kind == "file":
-            return Template(
-                open(path, encoding="utf-8").read(), filename=path, **self._keywords
-            )
+            with open(path, encoding="utf-8") as tmpl_file:
+                return Template(tmpl_file.read(), filename=path, **self._keywords)
         else:
             raise AttributeError("No template named " + name)
 
@@ -1177,7 +1163,7 @@ class GAE_Render(Render):
 render = Render
 # setup render for Google App Engine.
 try:
-    from google import appengine
+    from google import appengine  # noqa: F401
 
     render = Render = GAE_Render
 except ImportError:
@@ -1185,8 +1171,7 @@ except ImportError:
 
 
 def frender(path, **keywords):
-    """Creates a template from the given file path.
-    """
+    """Creates a template from the given file path."""
     return Template(open(path, encoding="utf-8").read(), filename=path, **keywords)
 
 
@@ -1249,94 +1234,94 @@ class SecurityError(Exception):
 
 
 ALLOWED_AST_NODES = [
-    "Interactive",
-    "Expression",
-    "Suite",
-    "FunctionDef",
-    "ClassDef",
-    "Return",
-    "Delete",
+    "Add",
+    "And",
     "Assign",
-    "AugAssign",
-    "alias",
-    #'Print', 'Repr',
-    "For",
-    "While",
-    "If",
-    "With",
-    "comprehension",
-    "NameConstant",
-    "arg",
-    #'Raise', 'TryExcept', 'TryFinally', 'Assert', 'Import',
-    #'ImportFrom', 'Exec', 'Global',
-    "Expr",
-    "Pass",
-    "Break",
-    "Continue",
-    "BoolOp",
-    "BinOp",
-    "UnaryOp",
-    "Lambda",
-    "IfExp",
-    "Dict",
-    "Module",
-    "arguments",
-    "keyword",
-    "Set",
-    "ListComp",
-    "SetComp",
-    "DictComp",
-    "GeneratorExp",
-    "Yield",
-    "Compare",
-    "Call",
-    "Num",
-    "Str",
     "Attribute",
-    "Subscript",
-    "Name",
-    "List",
-    "Tuple",
-    "Load",
-    "Store",
-    "Del",
+    "AugAssign",
     "AugLoad",
     "AugStore",
-    "Param",
-    "Ellipsis",
-    "Slice",
-    "ExtSlice",
-    "Index",
-    "And",
-    "Or",
-    "Add",
-    "Sub",
-    "Mult",
-    "Div",
-    "Mod",
-    "Pow",
-    "LShift",
-    "RShift",
+    "BinOp",
+    "BitAnd",
     "BitOr",
     "BitXor",
-    "BitAnd",
-    "FloorDiv",
-    "Invert",
-    "Not",
-    "UAdd",
-    "USub",
+    "BoolOp",
+    "Break",
+    "Call",
+    "ClassDef",
+    "Compare",
+    "Constant",
+    "Continue",
+    "Del",
+    "Delete",
+    "Dict",
+    "DictComp",
+    "Div",
+    "Ellipsis",
     "Eq",
-    "NotEq",
-    "Lt",
-    "LtE",
+    "ExceptHandler",
+    "Expr",
+    "Expression",
+    "ExtSlice",
+    "FloorDiv",
+    "For",
+    "FunctionDef",
+    "GeneratorExp",
     "Gt",
     "GtE",
+    "If",
+    "IfExp",
+    "In",
+    "Index",
+    "Interactive",
+    "Invert",
     "Is",
     "IsNot",
-    "In",
+    "JoinedStr",
+    "LShift",
+    "Lambda",
+    "List",
+    "ListComp",
+    "Load",
+    "Lt",
+    "LtE",
+    "Mod",
+    "Module",
+    "Mult",
+    "Name",
+    "NameConstant",
+    "Not",
+    "NotEq",
     "NotIn",
-    "ExceptHandler",
+    "Num",
+    "Or",
+    "Param",
+    "Pass",
+    "Pow",
+    "RShift",
+    "Return",
+    "Set",
+    "SetComp",
+    "Slice",
+    "Store",
+    "Str",
+    "Sub",
+    "Subscript",
+    "Suite",
+    "Tuple",
+    "UAdd",
+    "USub",
+    "UnaryOp",
+    "While",
+    "With",
+    "Yield",
+    "alias",
+    "arg",
+    "arguments",
+    "comprehension",
+    "keyword",
 ]
+# Assert Exec Global Import ImportFrom Print Raise Repr TryExcept TryFinally
 
 
 class SafeVisitor(ast.NodeVisitor):
@@ -1427,16 +1412,16 @@ class SafeVisitor(ast.NodeVisitor):
 class TemplateResult(MutableMapping):
     """Dictionary like object for storing template output.
 
-    The result of a template execution is usally a string, but sometimes it
+    The result of a template execution is usually a string, but sometimes it
     contains attributes set using $var. This class provides a simple
     dictionary like interface for storing the output of the template and the
-    attributes. The output is stored with a special key __body__. Convering
-    the the TemplateResult to string or unicode returns the value of __body__.
+    attributes. The output is stored with a special key __body__. Converting
+    the TemplateResult to string or unicode returns the value of __body__.
 
     When the template is in execution, the output is generated part by part
     and those parts are combined at the end. Parts are added to the
     TemplateResult by calling the `extend` method and the parts are combined
-    seemlessly when __body__ is accessed.
+    seamlessly when __body__ is accessed.
 
         >>> d = TemplateResult(__body__='hello, world', x='foo')
         >>> print(d)
@@ -1462,8 +1447,7 @@ class TemplateResult(MutableMapping):
         return self._d.keys()
 
     def _prepare_body(self):
-        """Prepare value of __body__ by joining parts.
-        """
+        """Prepare value of __body__ by joining parts."""
         if self._parts:
             value = u"".join(self._parts)
             self._parts[:] = []
@@ -1509,10 +1493,7 @@ class TemplateResult(MutableMapping):
 
     def __str__(self):
         self._prepare_body()
-        if PY2:
-            return self["__body__"].encode("utf-8")
-        else:
-            return self["__body__"]
+        return self["__body__"]
 
     def __repr__(self):
         self._prepare_body()
@@ -1536,7 +1517,7 @@ def test():
         >>> class TestResult:
         ...     def __init__(self, t): self.t = t
         ...     def __getattr__(self, name): return getattr(self.t, name)
-        ...     def __repr__(self): return repr(unicode(self.t) if PY2 else str(self.t))
+        ...     def __repr__(self): return str(self.t)
         ...
         >>> def t(code, **keywords):
         ...     tmpl = Template(code, **keywords)
